@@ -1,19 +1,19 @@
 import logging
 import os
+
 import shortuuid
 
-from dvc.stage import Stage
 from dvc.config import Config
-from dvc.exceptions import (
-    NotDvcRepoError,
-    UrlNotDvcRepoError,
-    GetDVCFileError,
-    OutputNotFoundError,
-)
-from dvc.path_info import PathInfo
+from dvc.exceptions import GetDVCFileError
+from dvc.exceptions import NotDvcRepoError
+from dvc.exceptions import OutputNotFoundError
+from dvc.exceptions import UrlNotDvcRepoError
 from dvc.external_repo import external_repo
+from dvc.path_info import PathInfo
+from dvc.stage import Stage
 from dvc.state import StateNoop
-from dvc.utils import remove, resolve_output
+from dvc.utils import remove
+from dvc.utils import resolve_output
 
 logger = logging.getLogger(__name__)
 
@@ -21,7 +21,6 @@ logger = logging.getLogger(__name__)
 @staticmethod
 def get(url, path, out=None, rev=None):
     out = resolve_output(path, out)
-    path = path.lstrip("/")
 
     if Stage.is_valid_filename(out):
         raise GetDVCFileError()
